/**
 * Class MyInput
 *
 * Modified by: Noah Singer
 *
 * use:
 *	int x = MyInput.readInt( );
 *	double y = MyInput.readDouble( );
 * 	String s = MyInput.readString( );
 */

import java.io.*;
import java.util.*;

/**
*	The MyInput class encapsulates the required functionality to read int, double and String data from
*	the console for use in a command-line driven application.  The location of the MyInput class must be part of
*	the systems classpath to be able to operate.
*/
public class MyInput
{
	static private StringTokenizer stok;
	static private BufferedReader br = new BufferedReader ( new InputStreamReader ( System.in ) , 1 );

	/**
	*	The readInt( ) method can be used from a calling class to read an integer value from the keyboard in a console.
	*	<br/><br/>
	*	<code>int x = MyInput.readInt( );</code>
	*	<br/><br/>
	*	The readInt( ) method uses a BufferedReader to accept input from the input buffer, tokenizes the input,
	*	keeping only the first "word", then converts that word into an integer that is then returned.
	*
	*	If a non integer value is read the method will display "Number Format Exception Encountered" on the console.
	*/
	public static int readInt( )
	{
		int i = 0;

		try
		{
			String str = br.readLine( );
			StringTokenizer stok = new StringTokenizer( str );
			i = new Integer( stok.nextToken( ) ).intValue( );
		}
		catch ( IOException ex )
		{
			System.out.println( "IOException Encountered" );
		}
		catch ( NumberFormatException ex )
		{
			System.out.println( "Number Format Exception Encountered" );
		}

		return i;
	}

	/**
	*	The readDouble( ) method can be used from a calling class to read an double value from the keyboard in a console.
	*	<br/><br/>
	*	<code>double x = MyInput.readDouble( );</code>
	*	<br/><br/>
	*	The readDouble( ) method uses a BufferedReader to accept input from the input buffer, tokenizes the input,
	*	keeping only the first "word", then converts that word into an double that is then returned.
	*
	*	If a non double value is read the method will display "Number Format Exception Encountered" on the console.
	*/
	public static double readDouble ( )
	{
		double d = 0;

		try
		{
			String str = br.readLine( );
			stok = new StringTokenizer( str );
			d = new Double( stok.nextToken( ) ).doubleValue( );
		}
		catch( IOException ex )
		{
			System.out.println( "IOException Encountered" );
		}
		catch ( NumberFormatException ex )
		{
			System.out.println( "Number Format Exception Encountered" );
		}

		return d;
	}

	/**
	*	The readString( ) method can be used from a calling class to read any String from the keyboard in a console.
	*	<br/><br/>
	*	<code>String x = MyInput.readString( );</code>
	*	<br/><br/>
	*	The readString( ) method uses a BufferedReader to accept input from the input buffer which is then returned.
	*/
	public static String readString ( )
		{
		String str = "Empty String";

		try
		{
			str = br.readLine( );
		}
		catch ( IOException ex )
		{
			System.out.println( "IOException Encountered" );
		}

		return str;
	}
}
